PLACEHOLDER_RESERVED_NAMES = [
    "user",
    "product",
    "item",
    "discount",
    "employee",
    "customer",
    "category",
    "group",
    "store",
    "organization",
    "date",
    "time",
    "datetime",
    "task",
    "layout",
    "modifier",
    "string",
    "number"
    ]

VARIABLE_RESERVED_NAMES = [
    "order",
    "product",
    "item",
    "discount",
    "modifier",
    "category",
    "user",
    "employee",
    "customer",
    "organization",
    "group",
    "store",
    "task",
    "layout"]

KEYWORDS = [
  # if...else if...else
  "if",
  "else",
  
  # Advanced expression
  "random",
  "unique",
  "first",
  "last",

  # AGG's
  "largest",
  "newest",
  "lowest",
  "smallest",
  "highest",
  "oldest",
  "count",
  "average",
  "max",
  "min",
  
  # Helpers
  "for",
  "foreach",
  "has",
  "in",
  "and",
  "into",
  "is",
  "isnt",
  "like",
  "or",
  "to",
  "before",
  "after",
  "equals",
  "equal",
  "not",
  
  # System
  "unset",
  "run",
  "where",
  "contains",
  "until",
  "pass",
  "push",
  "quit",
  "log",
  "restart",
  "set",
  "with",

  # periodically
  "every",
  "hourly",
  "daily",
  "weekly",
  "monthly",
  "quarterly",
  "yearly",
]

EVENTS = [
  "storeopens",
  "storecloses",
  "unsubscribe",
  "subscribe",
  "addtocart",
  "login",
  "logout",
  "signup",
  "tweet",
  "checkout",
  "reward",
  "sms",
  "print",
  "dialog",
  "wait",
  "email",
]
